==> question2answer-1.5-language-lt.zip: lt/qa-lang-profile.php <==
<?php
	
/*
	Question2Answer (c) Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-profile.php
	Version: See define()s at top of qa-include/qa-base.php
	Description: Language phrases for user profile page


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'1_chosen_as_best' => ' (1 pasirinktas kaip geriausias)',
		'1_down_vote' => '1 balsas "prieš"',
		'1_up_vote' => '1 balsas "už"',
		'1_with_best_chosen' => ' (1 su pasirinktu geriausiu atsakymu)',
		'activity_by_x' => 'Veikla iš ^',
		'answers' => 'Atsakymai:',
		'bonus_points' => 'Surinti taškai:',
		'comments' => 'Komentarai:',
		'extra_privileges' => 'Papildomos privilegijos:',
		'gave_out' => 'Išdalinta:',
		'my_account_title' => 'Mano paskyros detalės',
		'no_posts_by_x' => 'Nėra įrašų nuo ^',
		'permit_anon_view_ips' => 'IP adresų rodymas anoniminiams įrašams',
		'permit_close_q' => 'Bet kurio klausimo uždarymas',
		'permit_delete_hidden' => 'Paslėptų įrašų trynimas',
		'permit_edit_a' => 'Bet kurio atsakymo redagavimas',
		'permit_edit_c' => 'Bet kurio komentaro redagavimas',
		'permit_edit_q' => 'Bet kurio klausimo redagavimas',
		'permit_flag' => 'Netinkamų įrašų žymėjimas',
		'permit_hide_show' => 'Įrašų paslėpimas ir parodymas',
		'permit_moderate' => 'Įrašų patvirtinimas arba atmetimas',
		'permit_post_a' => 'Klausimų atsakinėjimas',
		'permit_post_c' => 'Komentavimas',
		'permit_post_q' => 'Klausimų uždavimas',
		'permit_recat' => 'Bet kurio klausimo kategorijos keitimas',
		'permit_retag' => 'Bet kurio klausimo žymių keitimas',
		'permit_select_a' => 'Geriausio atsakymo parinkimas',
		'permit_view_q_page' => 'Klausimų puslapių peržiūra',
		'permit_vote_a' => 'Balsavimas už atsakymus',
		'permit_vote_down' => 'Balsavimas "prieš"',
		'permit_vote_q' => 'Balsavimas už klausimus',
		'questions' => 'Klausimai:',
		'ranked_x' => ' (rangas #^)',
		'received' => 'Gauta:',
		'recent_activity_by_x' => 'Naujausia ^ veikla',
		'score' => 'Taškai:',
		'send_private_message' => ' - ^1siųsti privačias žinutes^2',
		'set_bonus_button' => 'Atnaujinti surinktus taškus',
		'title' => 'Pavadinimas:',
		'user_x' => 'Vartotojas ^',
		'voted_on' => 'Balsuota ties:',
		'x_chosen_as_best' => ' (^ pasirinta kaip geriausi)',
		'x_down_votes' => '^ balsai "prieš"',
		'x_up_votes' => '^ balsai "už"',
		'x_with_best_chosen' => ' (^ su pasirinktu geriausiu atsakymu)',
	);
	
/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.7-language-lt.zip: lt/qa-lang-profile.php <==
<?php
/*
	Question2Answer by Gideon Greenspan and contributors
	http://www.question2answer.org/

	File: qa-include/qa-lang-profile.php
	Description: Language phrases for user profile page


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'1_chosen_as_best' => ' (1 pasirinktas kaip geriausias)',
		'1_down_vote' => '1 balsas "prieš"',
		'1_up_vote' => '1 balsas "už"',
		'1_with_best_chosen' => ' (1 su pasirinktu geriausiu atsakymu)',
		'activity_by_x' => 'Veikla iš ^',
		'answers' => 'Atsakymai:',
		'answers_by_x' => 'Atsakymai iš ^',
		'bonus_points' => 'Surinti taškai:',
		'comments' => 'Komentarai:',
		'delete_pm_popup' => 'Ištrinti šitą privačią žinutę',
		'delete_wall_post_popup' => 'Ištrinti šį sienos įrašą',
		'extra_privileges' => 'Papildomos privilegijos:',
		'gave_out' => 'Išdalinta:',
		'my_account_title' => 'Mano paskyros detalės',
		'no_answers_by_x' => 'Nėra atsakymų iš ^',
		'no_posts_by_x' => 'Nėra įrašų iš ^',
		'no_questions_by_x' => 'Nėra klausimų iš ^',
		'permit_anon_view_ips' => 'IP adresų rodymas anoniminiams įrašams',
		'permit_close_q' => 'Bet kurio klausimo uždarymas',
		'permit_delete_hidden' => 'Paslėptų įrašų trynimas',
		'permit_edit_a' => 'Bet kurio atsakymo redagavimas',
		'permit_edit_c' => 'Bet kurio komentaro redagavimas',
		'permit_edit_q' => 'Bet kurio klausimo redagavimas',
		'permit_edit_silent' => 'Redaguoti įrašus be pranešimų',
		'permit_flag' => 'Netinkamų įrašų žymėjimas',
		'permit_hide_show' => 'Įrašų paslėpimas ir parodymas',
		'permit_moderate' => 'Įrašų patvirtinimas arba atmetimas',
		'permit_post_a' => 'Klausimų atsakinėjimas',
		'permit_post_c' => 'Komentavimas',
		'permit_post_q' => 'Klausimų uždavimas',
		'permit_post_wall' => 'Rašymas ant vartotojų sienų',
		'permit_recat' => 'Bet kurio klausimo kategorijos keitimas',
		'permit_retag' => 'Bet kurio klausimo žymių keitimas',
		'permit_select_a' => 'Geriausio atsakymo parinkimas',
		'permit_view_q_page' => 'Klausimų puslapių peržiūra',
		'permit_view_voters_flaggers' => 'Rodyti kas balsavo ar pažymėjo kaip netinkamą',
		'permit_vote_a' => 'Balsavimas už atsakymus',
		'permit_vote_down' => 'Balsavimas "prieš"',
		'permit_vote_q' => 'Balsavimas už klausimus',
		'post_wall_blocked' => 'Šis vartotojas neleidžia naujų įrašų ant savo sienos',
		'post_wall_button' => 'Pridėti sienos įrašą',
		'post_wall_empty' => 'Prašome įvesti įrašo tekstą',
		'post_wall_limit' => 'Šiuo metu jūs daugiau nebegalite rašyti sienos įrašų',
		'post_wall_must_be_approved' => 'Jūsų paskyra turi būti patvirtinta, kad galėtumėte rašyti ant šitos sienos.',
		'post_wall_must_confirm' => 'Prašome ^5patvirtinti jūsų el. pašto adresą^6, kad galėtumėte rašyti ant šitos sienos.',
		'post_wall_must_login' => 'Prašome ^1prisijungti^2 arba ^3užsiregistruoti^4, kad galėtumėte rašyti ant šitos sienos.',
		'questions' => 'Klausimai:',
		'questions_by_x' => 'Klausimai iš ^',
		'ranked_x' => ' (rangas #^)',
		'received' => 'Gauta:',
		'recent_activity_by_x' => 'Naujausia ^ veikla',
		'score' => 'Taškai:',
		'send_private_message' => ' - ^1siųsti privačias žinutes^2',
		'set_bonus_button' => 'Atnaujinti surinktus taškus',
		'title' => 'Pavadinimas:',
		'user_x' => 'Vartotojas ^',
		'voted_on' => 'Balsuota ties:',
		'wall_for_x' => '^ siena',
		'wall_view_more' => 'Daugiau sienos įrašų...',
		'x_chosen_as_best' => ' (^ pasirinta kaip geriausi)',
		'x_down_votes' => '^ balsai "prieš"',
		'x_up_votes' => '^ balsai "už"',
		'x_with_best_chosen' => ' (^ su pasirinktu geriausiu atsakymu)',
	);
	
	
/*
	Omit PHP closing tag to help avoid accidental output
*/
